@@ -1,5 +1,11 @@
 package Geo::Coder::Free::DB;
 
+=head1
+
+Geo::Coder::Free::DB
+
+=cut
+
 # Author Nigel Horne: njh@bandsman.co.uk
 # Copyright (C) 2015-2022, Nigel Horne
 
@@ -366,6 +372,9 @@ sub selectall_hash {
 	if(!$self->{no_entry}) {
 		$query .= ' ORDER BY entry';
 	}
+	if(!wantarray) {
+		$query .= ' LIMIT 1';
+	}
 	if($self->{'logger'}) {
 		if(defined($query_args[0])) {
 			$self->{'logger'}->debug("selectall_hash $query: ", join(', ', @query_args));
@@ -395,8 +404,9 @@ sub selectall_hash {
 
 		my @rc;
 		while(my $href = $sth->fetchrow_hashref()) {
+			# FIXME: Doesn't store in the cache
+			return $href if(!wantarray);
 			push @rc, $href;
-			last if(!wantarray);
 		}
 		if($c && wantarray) {
 			$c->set($key, \@rc, '1 hour');
